pub struct FloatDuration { /* private fields */ }Expand description
A time duration stored as a floating point quantity.
Unlike std::time::Duration or chrono::Duration, FloatDuration
aims to be convenient and fast to use in simulation and mathematical expressions
rather than to behave like a calendar or perfectly
accurately represent precise time scales.
Internally, a FloatDuration stores a single f64 number of floating-point seconds,
thus it is only as precise as the f64 type.
Implementations
Sourceimpl FloatDuration
impl FloatDuration
Sourcepub fn years(years: f64) -> FloatDuration
pub fn years(years: f64) -> FloatDuration
Create a new FloatDuration representing a number of years.
float_duration considers one year to be exactly 365 days, with
no consideration of leap years.
Sourcepub fn days(days: f64) -> FloatDuration
pub fn days(days: f64) -> FloatDuration
Create a new FloatDuration representing a number of days.
Sourcepub fn hours(hours: f64) -> FloatDuration
pub fn hours(hours: f64) -> FloatDuration
Create a new FloatDuration representing a number of hours.
Sourcepub fn minutes(mins: f64) -> FloatDuration
pub fn minutes(mins: f64) -> FloatDuration
Create a new FloatDuration representing a number of minutes.
Sourcepub fn seconds(secs: f64) -> FloatDuration
pub fn seconds(secs: f64) -> FloatDuration
Create a new FloatDuration representing a number of seconds.
Sourcepub fn milliseconds(millis: f64) -> FloatDuration
pub fn milliseconds(millis: f64) -> FloatDuration
Create a new FloatDuration representing a number of milliseconds.
Sourcepub fn microseconds(micros: f64) -> FloatDuration
pub fn microseconds(micros: f64) -> FloatDuration
Create a new FloatDuration representing a number of microseconds.
Sourcepub fn nanoseconds(nanos: f64) -> FloatDuration
pub fn nanoseconds(nanos: f64) -> FloatDuration
Create a new FloatDuration representing a number of nanoseconds.
Sourcepub fn as_years(&self) -> f64
pub fn as_years(&self) -> f64
Return the total number of fractional years represented by the FloatDuration.
float_duration considers one year to be exactly 365 days, with
no consideration of leap years.
Sourcepub fn as_days(&self) -> f64
pub fn as_days(&self) -> f64
Return the total number of fractional days represented by the FloatDuration.
Sourcepub fn as_hours(&self) -> f64
pub fn as_hours(&self) -> f64
Return the total number of fractional hours represented by the FloatDuration.
Sourcepub fn as_minutes(&self) -> f64
pub fn as_minutes(&self) -> f64
Return the total number of fractional minutes represented by the FloatDuration.
Sourcepub fn as_seconds(&self) -> f64
pub fn as_seconds(&self) -> f64
Return the total number of fractional seconds represented by the FloatDuration.
Sourcepub fn as_milliseconds(&self) -> f64
pub fn as_milliseconds(&self) -> f64
Return the total number of fractional milliseconds represented by the FloatDuration.
Sourcepub fn as_microseconds(&self) -> f64
pub fn as_microseconds(&self) -> f64
Return the total number of fractional microseconds represented by the FloatDuration.
Sourcepub fn as_nanoseconds(&self) -> f64
pub fn as_nanoseconds(&self) -> f64
Return the total number of fractional nanoseconds represented by the FloatDuration.
Sourcepub fn abs(self) -> FloatDuration
pub fn abs(self) -> FloatDuration
Compute the absolute value of this duration.
Sourcepub fn zero() -> FloatDuration
pub fn zero() -> FloatDuration
Return a new FloatDuration that represents zero elapsed time.
Sourcepub fn is_zero(&self) -> bool
pub fn is_zero(&self) -> bool
Returns true is this duration represents zero elapsed time (equals FloatDuration::zero()).
Sourcepub fn is_positive(&self) -> bool
pub fn is_positive(&self) -> bool
Returns true if the FloatDuration holds a positive amount of time.
Sourcepub fn is_negative(&self) -> bool
pub fn is_negative(&self) -> bool
Returns true if the FloatDuration holds a negative amount of time.
Sourcepub fn signum(&self) -> f64
pub fn signum(&self) -> f64
Return a number that represents the sign of self.
- 1.0 if the value is positive,
+0.0orINFINITY - -1.0 if the value is negative,
-0.0orNEG_INFINITY NANif the value isNAN
Sourcepub fn max(self, other: FloatDuration) -> FloatDuration
pub fn max(self, other: FloatDuration) -> FloatDuration
Return the maximum of two durations.
Sourcepub fn min(self, other: FloatDuration) -> FloatDuration
pub fn min(self, other: FloatDuration) -> FloatDuration
Return the minimum of two durations.
Sourcepub fn min_value() -> FloatDuration
pub fn min_value() -> FloatDuration
Return a new FloatDuration with the minimum possible value.
Sourcepub fn max_value() -> FloatDuration
pub fn max_value() -> FloatDuration
Return a new FloatDuration with the maximum possible value.
Sourcepub fn to_std(&self) -> Result<Duration, OutOfRangeError>
pub fn to_std(&self) -> Result<Duration, OutOfRangeError>
Create a std::time::Duration object from a FloatDuration.
Errors
std::time::Duration does not support negative values or seconds
greater than std::u64::MAX. This function will return a
DurationError::StdOutOfRange if the FloatDuration value is outside
of either of those bounds.
Sourcepub fn from_std(duration: Duration) -> FloatDuration
pub fn from_std(duration: Duration) -> FloatDuration
Create a FloatDuration object from a std::time::Duration.
Equivalent to using FloatDuration::from(duration)
Sourceimpl FloatDuration
impl FloatDuration
Sourcepub fn to_chrono(&self) -> Result<Duration, OutOfRangeError>
pub fn to_chrono(&self) -> Result<Duration, OutOfRangeError>
Create a chrono::Duration object from a FloatDuration.
Errors
Presently, the conversion to chrono::Duration first goes through
std::time::Duration and return an error if to_std returns an error.
Sourcepub fn from_chrono(duration: Duration) -> FloatDuration
pub fn from_chrono(duration: Duration) -> FloatDuration
Create a FloatDuration object from a chrono::Duration.
chrono::Duration does not provide a way to access sub-millisecond
precision if the duration is too large to be entirely represented as a single
value. Thus, if the absolute value of the total number of nanoseconds is
greater than i64::MAX, only millisecond precision will be captured.
Equivalent to using FloatDuration::from(duration)